[Libreoffice-commits] core.git: vcl/unx

Caolán McNamara (via logerrit) logerrit at kemper.freedesktop.org
Tue May 4 19:13:34 UTC 2021


 vcl/unx/gtk3/gtk3gtkinst.cxx |    8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

New commits:
commit ef78c7d93e4f170ac7a7f0307a8305052524eb53
Author:     Caolán McNamara <caolanm at redhat.com>
AuthorDate: Tue May 4 16:54:34 2021 +0100
Commit:     Caolán McNamara <caolanm at redhat.com>
CommitDate: Tue May 4 21:12:51 2021 +0200

    restore focus to the GtkEntry of GtkComboBoxText on menu popdown
    
    the font size/name dropdowns in the document toolbar should continue
    to restore focus to the document directly while typical ones should
    vcl-alike select the GtkEntry contents
    
    Change-Id: Ic6c6cd48362dac6e4476c42a4070a83cd50faa2b
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/115104
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/vcl/unx/gtk3/gtk3gtkinst.cxx b/vcl/unx/gtk3/gtk3gtkinst.cxx
index 65a530fd3370..afb3aeba724e 100644
--- a/vcl/unx/gtk3/gtk3gtkinst.cxx
+++ b/vcl/unx/gtk3/gtk3gtkinst.cxx
@@ -14684,11 +14684,13 @@ private:
         {
             m_bPopupActive = bIsShown;
             ComboBox::signal_popup_toggled();
-            if (!m_bPopupActive)
+            if (!m_bPopupActive && m_pEntry)
             {
-                //restore focus to the entry view when the popup is gone, which
+                disable_notify_events();
+                //restore focus to the GtkEntry when the popup is gone, which
                 //is what the vcl case does, to ease the transition a little
-                grab_focus();
+                gtk_widget_grab_focus(m_pEntry);
+                enable_notify_events();
             }
         }
     }


More information about the Libreoffice-commits mailing list